@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2014   Lukas F. Reichlin
+## Copyright (C) 2009-2015   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -22,28 +22,36 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: September 2009
-## Version: 0.1
+## Version: 0.2
 
-function retlti = __lti_group__ (lti1, lti2)
+function retlti = __lti_group__ (lti1, lti2, dim = "blkdiag")
 
-  retlti = lti ();
+  retlti = lti (:, :, :);
 
-  retlti.inname = [lti1.inname;
-                   lti2.inname];
+  if (any (strcmpi (dim, {"blkdiag", "horzcat"})))  # blkdiag, horzcat
+    retlti.inname = [lti1.inname; lti2.inname];
 
-  retlti.outname = [lti1.outname;
-                    lti2.outname];
-
-  if (nfields (lti1.ingroup) || nfields (lti2.ingroup))
-    m1 = numel (lti1.inname);
-    lti2_ingroup = structfun (@(x) x + m1, lti2.ingroup, "uniformoutput", false);
-    retlti.ingroup = __merge_struct__ (lti1.ingroup, lti2_ingroup, "in");
+    if (nfields2 (lti1.ingroup) || nfields2 (lti2.ingroup))
+      m1 = numel (lti1.inname);
+      lti2_ingroup = structfun (@(x) x + m1, lti2.ingroup, "uniformoutput", false);
+      retlti.ingroup = __merge_struct__ (lti1.ingroup, lti2_ingroup);
+    endif
+  else                                              # times, vertcat
+    retlti.inname = repmat ({""}, numel (lti1.inname), 1);
+    ## retlti.ingroup remains empty struct
   endif
-  
-  if (nfields (lti1.outgroup) || nfields (lti2.outgroup))
-    p1 = numel (lti1.outname);
-    lti2_outgroup = structfun (@(x) x + p1, lti2.outgroup, "uniformoutput", false);
-    retlti.outgroup = __merge_struct__ (lti1.outgroup, lti2_outgroup, "out");
+
+  if (any (strcmpi (dim, {"blkdiag", "vertcat"})))  # blkdiag, vertcat
+    retlti.outname = [lti1.outname; lti2.outname];
+
+    if (nfields2 (lti1.outgroup) || nfields2 (lti2.outgroup))
+      p1 = numel (lti1.outname);
+      lti2_outgroup = structfun (@(x) x + p1, lti2.outgroup, "uniformoutput", false);
+      retlti.outgroup = __merge_struct__ (lti1.outgroup, lti2_outgroup);
+    endif
+  else                                              # times, horzcat
+    retlti.outname = repmat ({""}, numel (lti1.outname), 1);
+    ## retlti.outgroup remains empty struct
   endif
 
   if (lti1.tsam == lti2.tsam)
@@ -63,17 +71,17 @@ function retlti = __lti_group__ (lti1, lti2)
 endfunction
 
 
-function ret = __merge_struct__ (a, b, iostr)
+function ret = __merge_struct__ (a, b)
 
   ## FIXME: this is too complicated;
   ##        isn't there a simple function for this task?
 
   ## bug #40224: orderfields (struct ()) errors out in Octave 3.6.4
-  ## therefore use nfields to check for empty structs
-  if (nfields (a))
+  ## therefore use nfields2 to check for empty structs
+  if (nfields2 (a))
     a = orderfields (a);
   endif
-  if (nfields (b))
+  if (nfields2 (b))
     b = orderfields (b);
   endif
 
