@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2014   Lukas F. Reichlin
+## Copyright (C) 2009-2015   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -21,14 +21,12 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: September 2009
-## Version: 0.2
+## Version: 0.3
 
 function [p, m, n] = __ss_dim__ (a, b, c, d, e = [])
 
-  ## TODO: create oct-file?
-
   if (! is_real_matrix (a, b, c, d, e))
-    error ("ss: system matrices must be real");
+    error ("ss: system matrices must be real-valued");
   endif
 
   [arows, acols] = size (a);
