@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2014   Lukas F. Reichlin
+## Copyright (C) 2009-2015   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -22,7 +22,7 @@
 ## If no output arguments are given, both gain and phase margin are plotted on a bode diagram.
 ## Otherwise, the margins and their corresponding frequencies are computed and returned.
 ## A more robust criterion to assess the stability of a feedback system is the sensitivity Ms
-## computed by command @command{sensitivity}.
+## computed by function @command{sensitivity}.
 ##
 ## @strong{Inputs}
 ## @table @var
@@ -46,7 +46,7 @@
 ## @end table
 ##
 ## @strong{Algorithm}@*
-## Uses command @command{roots} to calculate the frequencies
+## Uses function @command{roots} to calculate the frequencies
 ## @var{w_gamma}, @var{w_phi} from special polynomials created
 ## from the transfer function of @var{sys} as listed below
 ## in section @guillemetleft{}Equations@guillemetright{}.
@@ -142,7 +142,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: July 2009
-## Version: 0.9.1
+## Version: 0.9.2
 
 function [gamma_r, phi_r, w_gamma_r, w_phi_r] = margin (sys, tol = sqrt (eps))
 
@@ -278,7 +278,9 @@ function [gamma_r, phi_r, w_gamma_r, w_phi_r] = margin (sys, tol = sqrt (eps))
 
   if (nargout == 0)                                      # show bode diagram
 
-    [H, w] = __frequency_response__ (sys, false, "std");
+    [H, w] = __frequency_response__ ("margin", {sys});
+    H = H{1};
+    w = w{1};
 
     H = reshape (H, [], 1);
     mag_db = 20 * log10 (abs (H));
