@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2014   Lukas F. Reichlin
+Copyright (C) 2009-2015   Lukas F. Reichlin
 
 This file is part of LTI Syncope.
 
@@ -21,12 +21,13 @@ Return true if all arguments are matrices and false otherwise.
 
 Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 Created: June 2012
-Version: 0.1
+Version: 0.2
 
 */
 
 #include <octave/oct.h>
 
+// PKG_ADD: autoload ("is_matrix", "__control_helper_functions__.oct");    
 DEFUN_DLD (is_matrix, args, nargout,
    "-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {} is_matrix (@var{a}, @dots{})\n\
@@ -37,7 +38,7 @@ Avoid nasty stuff like @code{true = isreal (\"a\")}\n\
 @end deftypefn")
 {
     octave_value retval = true;
-    int nargin = args.length ();
+    octave_idx_type nargin = args.length ();
 
     if (nargin == 0)
     {
@@ -45,7 +46,7 @@ Avoid nasty stuff like @code{true = isreal (\"a\")}\n\
     }
     else
     {
-        for (int i = 0; i < nargin; i++)
+        for (octave_idx_type i = 0; i < nargin; i++)
         {
             if (args(i).ndims () != 2 || ! args(i).is_numeric_type ()
                 || ! (args(i).is_complex_type () || args(i).is_real_type ()))
