@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2014   Lukas F. Reichlin
+Copyright (C) 2009-2015   Lukas F. Reichlin
 
 This file is part of LTI Syncope.
 
@@ -17,27 +17,28 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
-Return true if argument is a real square matrix.
+Return true if all arguments are real-valued, square matrices and false otherwise.
 
 Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 Created: September 2010
-Version: 0.1
+Version: 0.2
 
 */
 
 #include <octave/oct.h>
 
+// PKG_ADD: autoload ("is_real_square_matrix", "__control_helper_functions__.oct");    
 DEFUN_DLD (is_real_square_matrix, args, nargout,
    "-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {} is_real_square_matrix (@var{a}, @dots{})\n\
-Return true if argument is a real square matrix.\n\
+Return true if all arguments are real-valued, square matrices and false otherwise.\n\
 @var{[]} is a valid square matrix.\n\
 Avoid nasty stuff like @code{true = isreal (\"a\")}\n\
 @seealso{is_real_matrix, is_real_vector, is_real_scalar}\n\
 @end deftypefn")
 {
     octave_value retval = true;
-    int nargin = args.length ();
+    octave_idx_type nargin = args.length ();
 
     if (nargin == 0)
     {
@@ -45,7 +46,7 @@ Avoid nasty stuff like @code{true = isreal (\"a\")}\n\
     }
     else
     {
-        for (int i = 0; i < nargin; i++)
+        for (octave_idx_type i = 0; i < nargin; i++)
         {
             if (args(i).ndims () != 2 || args(i).rows () != args(i).columns ()
                 || ! args(i).is_numeric_type () || ! args(i).is_real_type ())
