@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2014   Lukas F. Reichlin
+Copyright (C) 2009-2015   Lukas F. Reichlin
 
 This file is part of LTI Syncope.
 
@@ -23,7 +23,7 @@ Uses SLICOT AB13BD by courtesy of NICONET e.V.
 
 Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 Created: November 2009
-Version: 0.4
+Version: 0.5
 
 */
 
@@ -35,16 +35,16 @@ extern "C"
 { 
     double F77_FUNC (ab13bd, AB13BD)
                     (char& DICO, char& JOBN,
-                     int& N, int& M, int& P,
-                     double* A, int& LDA,
-                     double* B, int& LDB,
-                     double* C, int& LDC,
-                     double* D, int& LDD,
-                     int& NQ,
+                     octave_idx_type& N, octave_idx_type& M, octave_idx_type& P,
+                     double* A, octave_idx_type& LDA,
+                     double* B, octave_idx_type& LDB,
+                     double* C, octave_idx_type& LDC,
+                     double* D, octave_idx_type& LDD,
+                     octave_idx_type& NQ,
                      double& TOL,
-                     double* DWORK, int& LDWORK,
-                     int& IWARN,
-                     int& INFO);
+                     double* DWORK, octave_idx_type& LDWORK,
+                     octave_idx_type& IWARN,
+                     octave_idx_type& INFO);
 }
 
 // PKG_ADD: autoload ("__sl_ab13bd__", "__control_slicot_functions__.oct");    
@@ -54,7 +54,7 @@ Slicot AB13BD Release 5.\n\
 No argument checking.\n\
 For internal use only.")
 {
-    int nargin = args.length ();
+    octave_idx_type nargin = args.length ();
     octave_value_list retval;
     
     if (nargin != 5)
@@ -71,38 +71,38 @@ For internal use only.")
         Matrix b = args(1).matrix_value ();
         Matrix c = args(2).matrix_value ();
         Matrix d = args(3).matrix_value ();
-        int discrete = args(4).int_value ();
+        octave_idx_type discrete = args(4).int_value ();
 
         if (discrete == 0)
             dico = 'C';
         else
             dico = 'D';
         
-        int n = a.rows ();      // n: number of states
-        int m = b.columns ();   // m: number of inputs
-        int p = c.rows ();      // p: number of outputs
+        octave_idx_type n = a.rows ();      // n: number of states
+        octave_idx_type m = b.columns ();   // m: number of inputs
+        octave_idx_type p = c.rows ();      // p: number of outputs
         
-        int lda = max (1, a.rows ());
-        int ldb = max (1, b.rows ());
-        int ldc = max (1, c.rows ());
-        int ldd = max (1, d.rows ());
+        octave_idx_type lda = max (1, a.rows ());
+        octave_idx_type ldb = max (1, b.rows ());
+        octave_idx_type ldc = max (1, c.rows ());
+        octave_idx_type ldd = max (1, d.rows ());
         
         // arguments out
         double norm;
-        int nq;
+        octave_idx_type nq;
         
         // tolerance
         double tol = 0;
         
         // workspace
-        int ldwork = max (1, m*(n+m) + max (n*(n+5), m*(m+2), 4*p ),
+        octave_idx_type ldwork = max (1, m*(n+m) + max (n*(n+5), m*(m+2), 4*p ),
                              n*(max (n, p) + 4 ) + min (n, p));
 
         OCTAVE_LOCAL_BUFFER (double, dwork, ldwork);
         
         // error indicator
-        int iwarn;
-        int info;
+        octave_idx_type iwarn;
+        octave_idx_type info;
 
 
         // SLICOT routine AB13BD
