@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2014   Lukas F. Reichlin
+Copyright (C) 2009-2015   Lukas F. Reichlin
 
 This file is part of LTI Syncope.
 
@@ -23,7 +23,7 @@ Uses SLICOT AB13DD by courtesy of NICONET e.V.
 
 Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 Created: November 2009
-Version: 0.4
+Version: 0.5
 
 */
 
@@ -37,18 +37,18 @@ extern "C"
     int F77_FUNC (ab13dd, AB13DD)
                  (char& DICO, char& JOBE,
                   char& EQUIL, char& JOBD,
-                  int& N, int& M, int& P,
+                  octave_idx_type& N, octave_idx_type& M, octave_idx_type& P,
                   double* FPEAK,
-                  double* A, int& LDA,
-                  double* E, int& LDE,
-                  double* B, int& LDB,
-                  double* C, int& LDC,
-                  double* D, int& LDD,
+                  double* A, octave_idx_type& LDA,
+                  double* E, octave_idx_type& LDE,
+                  double* B, octave_idx_type& LDB,
+                  double* C, octave_idx_type& LDC,
+                  double* D, octave_idx_type& LDD,
                   double* GPEAK,
                   double& TOL,
-                  int* IWORK, double* DWORK, int& LDWORK,
-                  Complex* CWORK, int& LCWORK,
-                  int& INFO);
+                  octave_idx_type* IWORK, double* DWORK, octave_idx_type& LDWORK,
+                  Complex* CWORK, octave_idx_type& LCWORK,
+                  octave_idx_type& INFO);
 }
 
 // PKG_ADD: autoload ("__sl_ab13dd__", "__control_slicot_functions__.oct");    
@@ -58,7 +58,7 @@ Slicot AB13DD Release 5.0\n\
 No argument checking.\n\
 For internal use only.")
 {
-    int nargin = args.length ();
+    octave_idx_type nargin = args.length ();
     octave_value_list retval;
     
     if (nargin != 9)
@@ -78,10 +78,10 @@ For internal use only.")
         Matrix b = args(2).matrix_value ();
         Matrix c = args(3).matrix_value ();
         Matrix d = args(4).matrix_value ();
-        int discrete = args(5).int_value ();
-        int descriptor = args(6).int_value ();
+        octave_idx_type discrete = args(5).int_value ();
+        octave_idx_type descriptor = args(6).int_value ();
         double tol = args(7).double_value ();
-        const int scaled = args(8).int_value ();
+        const octave_idx_type scaled = args(8).int_value ();
         
         if (discrete == 0)
             dico = 'C';
@@ -98,15 +98,15 @@ For internal use only.")
         else
             equil = 'N';
 
-        int n = a.rows ();      // n: number of states
-        int m = b.columns ();   // m: number of inputs
-        int p = c.rows ();      // p: number of outputs
+        octave_idx_type n = a.rows ();      // n: number of states
+        octave_idx_type m = b.columns ();   // m: number of inputs
+        octave_idx_type p = c.rows ();      // p: number of outputs
         
-        int lda = max (1, n);
-        int lde = max (1, n);
-        int ldb = max (1, n);
-        int ldc = max (1, p);
-        int ldd = max (1, p);
+        octave_idx_type lda = max (1, n);
+        octave_idx_type lde = max (1, n);
+        octave_idx_type ldb = max (1, n);
+        octave_idx_type ldc = max (1, p);
+        octave_idx_type ldd = max (1, p);
         
         ColumnVector fpeak (2);
         ColumnVector gpeak (2);
@@ -115,16 +115,16 @@ For internal use only.")
         fpeak(1) = 1;
         
         // workspace
-        int ldwork = max (1, 15*n*n + p*p + m*m + (6*n+3)*(p+m) + 4*p*m +
+        octave_idx_type ldwork = max (1, 15*n*n + p*p + m*m + (6*n+3)*(p+m) + 4*p*m +
                           n*m + 22*n + 7*min(p,m));
-        int lcwork = max (1, (n+m)*(n+p) + 2*min(p,m) + max(p,m));
+        octave_idx_type lcwork = max (1, (n+m)*(n+p) + 2*min(p,m) + max(p,m));
         
-        OCTAVE_LOCAL_BUFFER (int, iwork, n);
+        OCTAVE_LOCAL_BUFFER (octave_idx_type, iwork, n);
         OCTAVE_LOCAL_BUFFER (double, dwork, ldwork);
         OCTAVE_LOCAL_BUFFER (Complex, cwork, lcwork);
         
         // error indicator
-        int info;
+        octave_idx_type info;
 
 
         // SLICOT routine AB13DD
