@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2014   Lukas F. Reichlin
+Copyright (C) 2009-2015   Lukas F. Reichlin
 
 This file is part of LTI Syncope.
 
@@ -23,7 +23,7 @@ Uses SLICOT SB10ZD by courtesy of NICONET e.V.
 
 Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 Created: August 2011
-Version: 0.3
+Version: 0.4
 
 */
 
@@ -34,22 +34,22 @@ Version: 0.3
 extern "C"
 { 
     int F77_FUNC (sb10zd, SB10ZD)
-                 (int& N, int& M, int& NP,
-                  double* A, int& LDA,
-                  double* B, int& LDB,
-                  double* C, int& LDC,
-                  double* D, int& LDD,
+                 (octave_idx_type& N, octave_idx_type& M, octave_idx_type& NP,
+                  double* A, octave_idx_type& LDA,
+                  double* B, octave_idx_type& LDB,
+                  double* C, octave_idx_type& LDC,
+                  double* D, octave_idx_type& LDD,
                   double& FACTOR,
-                  double* AK, int& LDAK,
-                  double* BK, int& LDBK,
-                  double* CK, int& LDCK,
-                  double* DK, int& LDDK,
+                  double* AK, octave_idx_type& LDAK,
+                  double* BK, octave_idx_type& LDBK,
+                  double* CK, octave_idx_type& LDCK,
+                  double* DK, octave_idx_type& LDDK,
                   double* RCOND,
                   double& TOL,
-                  int* IWORK,
-                  double* DWORK, int& LDWORK,
+                  octave_idx_type* IWORK,
+                  double* DWORK, octave_idx_type& LDWORK,
                   bool* BWORK,
-                  int& INFO);
+                  octave_idx_type& INFO);
 }
 
 // PKG_ADD: autoload ("__sl_sb10zd__", "__control_slicot_functions__.oct");    
@@ -59,7 +59,7 @@ Slicot SB10ZD Release 5.0\n\
 No argument checking.\n\
 For internal use only.")
 {
-    int nargin = args.length ();
+    octave_idx_type nargin = args.length ();
     octave_value_list retval;
     
     if (nargin != 6)
@@ -77,19 +77,19 @@ For internal use only.")
         double factor = args(4).double_value ();
         double tol = args(5).double_value ();
         
-        int n = a.rows ();      // n: number of states
-        int m = b.columns ();   // m: number of inputs
-        int np = c.rows ();     // np: number of outputs
+        octave_idx_type n = a.rows ();      // n: number of states
+        octave_idx_type m = b.columns ();   // m: number of inputs
+        octave_idx_type np = c.rows ();     // np: number of outputs
         
-        int lda = max (1, n);
-        int ldb = max (1, n);
-        int ldc = max (1, np);
-        int ldd = max (1, np);
+        octave_idx_type lda = max (1, n);
+        octave_idx_type ldb = max (1, n);
+        octave_idx_type ldc = max (1, np);
+        octave_idx_type ldd = max (1, np);
         
-        int ldak = max (1, n);
-        int ldbk = max (1, n);
-        int ldck = max (1, m);
-        int lddk = max (1, m);
+        octave_idx_type ldak = max (1, n);
+        octave_idx_type ldbk = max (1, n);
+        octave_idx_type ldck = max (1, m);
+        octave_idx_type lddk = max (1, m);
         
         // arguments out
         Matrix ak (ldak, n);
@@ -99,17 +99,17 @@ For internal use only.")
         ColumnVector rcond (6);
         
         // workspace
-        int liwork = 2 * max (n, m+np);
-        int ldwork = 16*n*n + 5*m*m + 7*np*np + 6*m*n + 7*m*np +
+        octave_idx_type liwork = 2 * max (n, m+np);
+        octave_idx_type ldwork = 16*n*n + 5*m*m + 7*np*np + 6*m*n + 7*m*np +
                      7*n*np + 6*n + 2*(m + np) +
                      max (14*n+23, 16*n, 2*m-1, 2*np-1);
 
-        OCTAVE_LOCAL_BUFFER (int, iwork, liwork);
+        OCTAVE_LOCAL_BUFFER (octave_idx_type, iwork, liwork);
         OCTAVE_LOCAL_BUFFER (double, dwork, ldwork);
         OCTAVE_LOCAL_BUFFER (bool, bwork, 2*n);
         
         // error indicator
-        int info;
+        octave_idx_type info;
 
 
         // SLICOT routine SB10ZD
