@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2014   Lukas F. Reichlin
+Copyright (C) 2009-2015   Lukas F. Reichlin
 
 This file is part of LTI Syncope.
 
@@ -23,7 +23,7 @@ Uses SLICOT SG02AD by courtesy of NICONET e.V.
 
 Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 Created: October 2010
-Version: 0.3
+Version: 0.4
 
 */
 
@@ -39,25 +39,25 @@ extern "C"
                   char& FACT, char& UPLO,
                   char& JOBL, char& SCAL,
                   char& SORT, char& ACC,
-                  int& N, int& M, int& P,
-                  double* A, int& LDA,
-                  double* E, int& LDE,
-                  double* B, int& LDB,
-                  double* Q, int& LDQ,
-                  double* R, int& LDR,
-                  double* L, int& LDL,
+                  octave_idx_type& N, octave_idx_type& M, octave_idx_type& P,
+                  double* A, octave_idx_type& LDA,
+                  double* E, octave_idx_type& LDE,
+                  double* B, octave_idx_type& LDB,
+                  double* Q, octave_idx_type& LDQ,
+                  double* R, octave_idx_type& LDR,
+                  double* L, octave_idx_type& LDL,
                   double& RCONDU,
-                  double* X, int& LDX,
+                  double* X, octave_idx_type& LDX,
                   double* ALFAR, double* ALFAI,
                   double* BETA,
-                  double* S, int& LDS,
-                  double* T, int& LDT,
-                  double* U, int& LDU,
+                  double* S, octave_idx_type& LDS,
+                  double* T, octave_idx_type& LDT,
+                  double* U, octave_idx_type& LDU,
                   double& TOL,
-                  int* IWORK,
-                  double* DWORK, int& LDWORK,
+                  octave_idx_type* IWORK,
+                  double* DWORK, octave_idx_type& LDWORK,
                   bool* BWORK,
-                  int& IWARN, int& INFO);
+                  octave_idx_type& IWARN, octave_idx_type& INFO);
 }
 
 // PKG_ADD: autoload ("__sl_sg02ad__", "__control_slicot_functions__.oct");    
@@ -67,7 +67,7 @@ Slicot SG02AD Release 5.0\n\
 No argument checking.\n\
 For internal use only.")
 {
-    int nargin = args.length ();
+    octave_idx_type nargin = args.length ();
     octave_value_list retval;
 
     if (nargin != 8)
@@ -92,8 +92,8 @@ For internal use only.")
         Matrix q = args(3).matrix_value ();
         Matrix r = args(4).matrix_value ();
         Matrix l = args(5).matrix_value ();
-        int discrete = args(6).int_value ();
-        int ijobl = args(7).int_value ();
+        octave_idx_type discrete = args(6).int_value ();
+        octave_idx_type ijobl = args(7).int_value ();
 
         if (discrete == 0)
             dico = 'C';
@@ -105,53 +105,53 @@ For internal use only.")
         else
             jobl = 'N';
 
-        int n = a.rows ();      // n: number of states
-        int m = b.columns ();   // m: number of inputs
-        int p = 0;              // p: number of outputs, not used because FACT = 'N'
+        octave_idx_type n = a.rows ();      // n: number of states
+        octave_idx_type m = b.columns ();   // m: number of inputs
+        octave_idx_type p = 0;              // p: number of outputs, not used because FACT = 'N'
 
-        int lda = max (1, n);
-        int lde = max (1, n);
-        int ldb = max (1, n);
-        int ldq = max (1, n);
-        int ldr = max (1, m);
-        int ldl = max (1, n);
+        octave_idx_type lda = max (1, n);
+        octave_idx_type lde = max (1, n);
+        octave_idx_type ldb = max (1, n);
+        octave_idx_type ldq = max (1, n);
+        octave_idx_type ldr = max (1, m);
+        octave_idx_type ldl = max (1, n);
 
         // arguments out
         double rcondu;
 
-        int ldx = max (1, n);
+        octave_idx_type ldx = max (1, n);
         Matrix x (ldx, n);
 
-        int nu = 2*n;
+        octave_idx_type nu = 2*n;
         ColumnVector alfar (nu);
         ColumnVector alfai (nu);
         ColumnVector beta (nu);
 
         // unused output arguments
-        int lds = max (1, 2*n + m);
+        octave_idx_type lds = max (1, 2*n + m);
         OCTAVE_LOCAL_BUFFER (double, s, lds * lds);
 
-        int ldt = max (1, 2*n + m);
+        octave_idx_type ldt = max (1, 2*n + m);
         OCTAVE_LOCAL_BUFFER (double, t, ldt * 2*n);
 
-        int ldu = max (1, 2*n);
+        octave_idx_type ldu = max (1, 2*n);
         OCTAVE_LOCAL_BUFFER (double, u, ldu * 2*n);
 
         // tolerance
         double tol = 0;  // use default value
 
         // workspace
-        int liwork = max (1, m, 2*n);
-        OCTAVE_LOCAL_BUFFER (int, iwork, liwork);
+        octave_idx_type liwork = max (1, m, 2*n);
+        OCTAVE_LOCAL_BUFFER (octave_idx_type, iwork, liwork);
 
-        int ldwork = max (7*(2*n + 1) + 16, 16*n, 2*n + m, 3*m);
+        octave_idx_type ldwork = max (7*(2*n + 1) + 16, 16*n, 2*n + m, 3*m);
         OCTAVE_LOCAL_BUFFER (double, dwork, ldwork);
 
         OCTAVE_LOCAL_BUFFER (bool, bwork, 2*n);
 
         // error indicator
-        int iwarn;
-        int info;
+        octave_idx_type iwarn;
+        octave_idx_type info;
 
 
         // SLICOT routine SG02AD
