@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2014   Lukas F. Reichlin
+Copyright (C) 2009-2015   Lukas F. Reichlin
 
 This file is part of LTI Syncope.
 
@@ -21,7 +21,7 @@ Gain of descriptor state-space models.  Based on SLICOT TB04BX.f.
 
 Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 Created: March 2011
-Version: 0.1
+Version: 0.2
 
 */
 
@@ -34,8 +34,8 @@ Version: 0.1
 extern "C"
 { 
     int F77_FUNC (tg04bx, TG04BX)
-                 (int& IP, int& IZ,
-                  double* A, int& LDA,
+                 (octave_idx_type& IP, octave_idx_type& IZ,
+                  double* A, octave_idx_type& LDA,
                   double* E,
                   double* B,
                   double* C,
@@ -43,7 +43,7 @@ extern "C"
                   double* PR, double* PI,
                   double* ZR, double* ZI,
                   double& GAIN,
-                  int* IWORK);
+                  octave_idx_type* IWORK);
 }
 
 // PKG_ADD: autoload ("__sl_tg04bx__", "__control_slicot_functions__.oct");    
@@ -53,7 +53,7 @@ Slicot TG04BX Release 5.0\n\
 No argument checking.\n\
 For internal use only.")
 {
-    int nargin = args.length ();
+    octave_idx_type nargin = args.length ();
     octave_value_list retval;
     
     if (nargin != 9)
@@ -75,9 +75,9 @@ For internal use only.")
         ColumnVector zr = args(7).column_vector_value ();
         ColumnVector zi = args(8).column_vector_value ();
 
-        int n = a.rows ();      // n: number of states
-        int ip = pr.length ();  // ip: number of finite poles
-        int iz = zr.length ();  // iz: number of zeros
+        octave_idx_type n = a.rows ();      // n: number of states
+        octave_idx_type ip = pr.length ();  // ip: number of finite poles
+        octave_idx_type iz = zr.length ();  // iz: number of zeros
         
         // For ss, IP = n is always true.
         // However, dss models with poles at infinity
@@ -86,13 +86,13 @@ For internal use only.")
         // Take pr.length == pi.length == ip for granted,
         // and the same for iz, zr and zi.
         
-        int lda = max (1, n);
+        octave_idx_type lda = max (1, n);
 
         // arguments out
         double gain;
 
         // workspace
-        OCTAVE_LOCAL_BUFFER (int, iwork, lda);
+        OCTAVE_LOCAL_BUFFER (octave_idx_type, iwork, lda);
 
         
         F77_XFCN (tg04bx, TG04BX,
